@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 1999, 2020, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 1999, 2024, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -38,10 +38,10 @@ class VersionProps {
 
     // This field is read by HotSpot
     private static final String java_version =
-        "17.0.11";
+        "17.0.14";
 
     private static final String java_version_date =
-        "2024-04-16";
+        "2025-01-21";
 
     // This field is read by HotSpot
     private static final String java_runtime_name =
@@ -49,16 +49,16 @@ class VersionProps {
 
     // This field is read by HotSpot
     private static final String java_runtime_version =
-        "17.0.11+9";
+        "17.0.14+7";
 
     private static final String VERSION_NUMBER =
-        "17.0.11";
+        "17.0.14";
 
     private static final String VERSION_SPECIFICATION =
         "17";
 
     private static final String VERSION_BUILD =
-        "9";
+        "7";
 
     private static final String VERSION_PRE =
         "";
@@ -73,7 +73,7 @@ class VersionProps {
         "61.0";
 
     private static final String VENDOR =
-        "N/A";
+        "Arch Linux";
 
     private static final String VENDOR_URL =
         "https://openjdk.java.net/";
@@ -109,6 +109,7 @@ class VersionProps {
         props.put("java.class.version", CLASSFILE_MAJOR_MINOR);
 
         props.put("java.specification.version", VERSION_SPECIFICATION);
+        props.put("java.specification.maintenance.version", "1");
         props.put("java.specification.name", "Java Platform API Specification");
         props.put("java.specification.vendor", "Oracle Corporation");
 
